@@ -2,4 +2,4 @@ from .sqlalchemy import SQLAlchemy
 from .db import base
 
 db = SQLAlchemy()
-db.register_base(base)
\ No newline at end of file
+# db.register_base(base)
\ No newline at end of file
